@@ -1,7 +1,7 @@
 /* bspline/test.c
  *
  * Copyright (C) 2006, 2007, 2009 Brian Gough
- * Copyright (C) 2008 Rhys Ulerich
+ * Copyright (C) 2008, 2011 Rhys Ulerich
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include <gsl/gsl_nan.h>
 
 void
-test_bspline(gsl_bspline_workspace * bw, gsl_bspline_deriv_workspace * dbw)
+test_bspline(gsl_bspline_workspace * bw)
 {
   gsl_vector *B;
   gsl_matrix *dB;
@@ -68,7 +68,7 @@ test_bspline(gsl_bspline_workspace * bw, gsl_bspline_deriv_workspace * dbw)
     {
       double xi = a + (b - a) * (i / (n - 1.0));
       gsl_bspline_eval(xi, B, bw);
-      gsl_bspline_deriv_eval(xi, 0, dB, bw, dbw);
+      gsl_bspline_deriv_eval(xi, 0, dB, bw);
 
       for (j = 0; j < ncoeffs; j++)
         {
@@ -100,10 +100,8 @@ main(int argc, char **argv)
         {
           double a = -1.23 * order, b = 45.6 * order;
           gsl_bspline_workspace *bw = gsl_bspline_alloc(order, breakpoints);
-          gsl_bspline_deriv_workspace *dbw = gsl_bspline_deriv_alloc(order);
           gsl_bspline_knots_uniform(a, b, bw);
-          test_bspline(bw, dbw);
-          gsl_bspline_deriv_free(dbw);
+          test_bspline(bw);
           gsl_bspline_free(bw);
         }
     }
@@ -115,7 +113,6 @@ main(int argc, char **argv)
         {
           double a = -1.23 * order, b = 45.6 * order;
           gsl_bspline_workspace *bw = gsl_bspline_alloc(order, breakpoints);
-          gsl_bspline_deriv_workspace *dbw = gsl_bspline_deriv_alloc(order);
           gsl_vector *k = gsl_vector_alloc(breakpoints);
           for (i = 0; i < breakpoints; i++)
             {
@@ -125,9 +122,8 @@ main(int argc, char **argv)
               gsl_vector_set(k, i, x);
             };
           gsl_bspline_knots(k, bw);
-          test_bspline(bw, dbw);
+          test_bspline(bw);
           gsl_vector_free(k);
-          gsl_bspline_deriv_free(dbw);
           gsl_bspline_free(bw);
         }
     }
@@ -147,7 +143,6 @@ main(int argc, char **argv)
     };
 
     gsl_bspline_workspace *bw = gsl_bspline_alloc(2, 3);
-    gsl_bspline_deriv_workspace *dbw = gsl_bspline_deriv_alloc(2);
     gsl_matrix *dB = gsl_matrix_alloc(gsl_bspline_ncoeffs(bw),
                                       gsl_bspline_order(bw) + 1);
 
@@ -163,7 +158,7 @@ main(int argc, char **argv)
         /* Initialize dB with poison to ensure we overwrite it */
         gsl_matrix_set_all(dB, GSL_NAN);
 
-        gsl_bspline_deriv_eval(xloc[i], gsl_bspline_order(bw), dB, bw, dbw);
+        gsl_bspline_deriv_eval(xloc[i], gsl_bspline_order(bw), dB, bw);
         for (j = 0; j < gsl_bspline_ncoeffs(bw) ; ++j)
           {
             /* check basis function 1st deriv */
@@ -183,7 +178,6 @@ main(int argc, char **argv)
       }
 
     gsl_matrix_free(dB);
-    gsl_bspline_deriv_free(dbw);
     gsl_bspline_free(bw);
     gsl_vector_free(breakpts);
   }
@@ -219,7 +213,6 @@ main(int argc, char **argv)
     };
 
     gsl_bspline_workspace *bw = gsl_bspline_alloc(3, 5);
-    gsl_bspline_deriv_workspace *dbw = gsl_bspline_deriv_alloc(3);
 
     gsl_matrix *dB = gsl_matrix_alloc(gsl_bspline_ncoeffs(bw),
                                       gsl_bspline_order(bw) + 1);
@@ -236,7 +229,7 @@ main(int argc, char **argv)
       {
         /* Initialize dB with poison to ensure we overwrite it */
         gsl_matrix_set_all(dB, GSL_NAN);
-        gsl_bspline_deriv_eval(xloc[i], gsl_bspline_order(bw), dB, bw, dbw);
+        gsl_bspline_deriv_eval(xloc[i], gsl_bspline_order(bw), dB, bw);
 
         /* check basis function evaluation */
         for (j = 0; j < gsl_bspline_ncoeffs(bw); ++j)
@@ -262,7 +255,6 @@ main(int argc, char **argv)
       }
 
     gsl_matrix_free(dB);
-    gsl_bspline_deriv_free(dbw);
     gsl_bspline_free(bw);
     gsl_vector_free(breakpts);
   }
@@ -381,5 +373,146 @@ main(int argc, char **argv)
     gsl_bspline_free(w);
   }
 
+  /* Knots computed from prescribed Greville abscissae for k = 4 */
+  {
+    size_t i; /* looping */
+
+    /* Test parameters */
+    const size_t k = 4;
+    const double abscissae_data[] = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0 };
+    const size_t nabscissae       = sizeof(abscissae_data)/sizeof(abscissae_data[0]);
+
+    /* Expected results */
+    const double bpoint_data[]    = { 1.0, 4.0, 4.0, 4.0, 7.0 };
+    const size_t nbreak           = sizeof(bpoint_data)/sizeof(bpoint_data[0]);
+
+    /* Compute knots from Greville abscissae */
+    double abserr;
+    gsl_vector_const_view abscissae
+        = gsl_vector_const_view_array(abscissae_data, nabscissae);
+    gsl_bspline_workspace *w = gsl_bspline_alloc(k, nbreak);
+    gsl_bspline_knots_greville(&abscissae.vector, w, &abserr);
+
+    for (i = 0; i < nbreak; ++i)
+      {
+        gsl_test_abs(gsl_bspline_breakpoint(i,w), bpoint_data[i], GSL_DBL_EPSILON*50,
+            "b-spline k=%d knots_greville breakpoint #%d", k, i);
+      }
+    gsl_test_abs(abserr, 0.0, GSL_DBL_EPSILON*15,
+        "b-spline k=%d nbreak=%d knots_greville abserr", k, nbreak);
+
+    gsl_bspline_free(w);
+  }
+
+  /* Knots computed from prescribed Greville abscissae for k = 8 */
+  {
+    size_t i; /* looping */
+
+    /* Test parameters */
+    const size_t k = 8;
+
+    const double abscissae_data[] = { 1.0, 10.0/7, 13.0/7, 16.0/7, 22.0/7,
+                                      4.0, 34.0/7, 40.0/7, 43.0/7, 46.0/7, 7.0 };
+    const size_t nabscissae       = sizeof(abscissae_data)/sizeof(abscissae_data[0]);
+
+    /* Expected results */
+    const double bpoint_data[]    = { 1.0, 4.0, 4.0, 4.0, 7.0 };
+    const size_t nbreak           = sizeof(bpoint_data)/sizeof(bpoint_data[0]);
+
+    /* Compute knots from Greville abscissae */
+    double abserr;
+    gsl_vector_const_view abscissae
+        = gsl_vector_const_view_array(abscissae_data, nabscissae);
+    gsl_bspline_workspace *w = gsl_bspline_alloc(k, nbreak);
+    gsl_bspline_knots_greville(&abscissae.vector, w, &abserr);
+
+    for (i = 0; i < nbreak; ++i)
+      {
+        gsl_test_abs(gsl_bspline_breakpoint(i,w), bpoint_data[i], GSL_DBL_EPSILON*50,
+            "b-spline k=%d knots_greville breakpoint #%d", k, i);
+      }
+    gsl_test_abs(abserr, 0.0, GSL_DBL_EPSILON*15,
+        "b-spline k=%d nbreak=%d knots_greville abserr", k, nbreak);
+
+    gsl_bspline_free(w);
+  }
+
+  /* Knots computed from prescribed Greville abscissae for k = 2 */
+  /* Not an interesting calculation but checks the k = 2 edge case */
+  {
+    size_t i; /* looping */
+
+    /* Test parameters */
+    const size_t k = 2;
+    const double abscissae_data[] = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0 };
+    const size_t nabscissae       = sizeof(abscissae_data)/sizeof(abscissae_data[0]);
+
+    /* Expected results */
+    const double bpoint_data[]    = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0 };
+    const size_t nbreak           = sizeof(bpoint_data)/sizeof(bpoint_data[0]);
+
+    /* Compute knots from Greville abscissae */
+    double abserr;
+    gsl_vector_const_view abscissae
+        = gsl_vector_const_view_array(abscissae_data, nabscissae);
+    gsl_bspline_workspace *w = gsl_bspline_alloc(k, nbreak);
+    gsl_bspline_knots_greville(&abscissae.vector, w, &abserr);
+
+    for (i = 0; i < nbreak; ++i)
+      {
+        gsl_test_abs(gsl_bspline_breakpoint(i,w), bpoint_data[i], GSL_DBL_EPSILON,
+            "b-spline k=%d knots_greville breakpoint #%d", k, i);
+      }
+    gsl_test_abs(abserr, 0.0, GSL_DBL_EPSILON,
+        "b-spline k=%d nbreak=%d knots_greville abserr", k, nbreak);
+
+    gsl_bspline_free(w);
+  }
+
+  /* Knots computed from prescribed abscissae for edge case when nbreak = 2 */
+  {
+    size_t i; /* looping */
+
+    /* Test parameters */
+    const size_t k = 4;
+    double abscissae_data[] = { 1.0, 3.0, 5.0, 7.0 };
+    const size_t nabscissae = sizeof(abscissae_data)/sizeof(abscissae_data[0]);
+
+    /* Expected results */
+    const double bpoint_data[] = { 1.0, 7.0 };
+    const size_t nbreak        = sizeof(bpoint_data)/sizeof(bpoint_data[0]);
+
+    /* Compute knots from Greville abscissae where abscissae are recoverable */
+    double abserr;
+    gsl_vector_view abscissae
+        = gsl_vector_view_array(abscissae_data, nabscissae);
+    gsl_bspline_workspace *w = gsl_bspline_alloc(k, nbreak);
+    gsl_bspline_knots_greville(&abscissae.vector, w, &abserr);
+
+    /* Check recovery of breakpoints and abscissae */
+    for (i = 0; i < nbreak; ++i)
+      {
+        gsl_test_abs(gsl_bspline_breakpoint(i,w), bpoint_data[i], GSL_DBL_EPSILON,
+            "b-spline k=%d knots_greville breakpoint #%d", k, i);
+      }
+    gsl_test_abs(abserr, 0.0, GSL_DBL_EPSILON,
+        "b-spline k=%d nbreak=%d knots_greville abserr", k, nbreak);
+
+    /* Modify interior abscissae so they cannot be recovered with nbreak = 2 */
+    /* Then recompute breakpoints and check that abserr is as expected */
+    abscissae_data[1] -= 1;
+    abscissae_data[2] += 1;
+    gsl_bspline_knots_greville(&abscissae.vector, w, &abserr);
+    for (i = 0; i < nbreak; ++i)
+      {
+        gsl_test_abs(gsl_bspline_breakpoint(i,w), bpoint_data[i], GSL_DBL_EPSILON,
+            "b-spline k=%d knots_greville breakpoint #%d", k, i);
+      }
+    gsl_test_abs(abserr, /* deliberate error */ 2.0, GSL_DBL_EPSILON,
+        "b-spline k=%d nbreak=%d knots_greville abserr large", k, nbreak);
+
+    gsl_bspline_free(w);
+  }
+
   exit(gsl_test_summary());
 }
