@@ -4,7 +4,7 @@ main(void)
   double par[5] = {1.0, 2.0, 10.0, 20.0, 30.0};
 
   const gsl_multimin_fminimizer_type *T = 
-    gsl_multimin_fminimizer_nmsimplex;
+    gsl_multimin_fminimizer_nmsimplex2;
   gsl_multimin_fminimizer *s = NULL;
   gsl_vector *ss, *x;
   gsl_multimin_function minex_func;
@@ -24,8 +24,8 @@ main(void)
 
   /* Initialize method and iterate */
   minex_func.n = 2;
-  minex_func.f = &my_f;
-  minex_func.params = (void *)&par;
+  minex_func.f = my_f;
+  minex_func.params = par;
 
   s = gsl_multimin_fminimizer_alloc (T, 2);
   gsl_multimin_fminimizer_set (s, &minex_func, x, ss);
@@ -46,7 +46,7 @@ main(void)
           printf ("converged to minimum at\n");
         }
 
-      printf ("%5d %10.3e %10.3ef f() = %7.3f size = %.3f\n", 
+      printf ("%5d %10.3e %10.3e f() = %7.3f size = %.3f\n", 
               iter,
               gsl_vector_get (s->x, 0), 
               gsl_vector_get (s->x, 1), 
