@@ -1,10 +1,10 @@
 /* fft/c_pass_7.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -71,7 +71,7 @@ FUNCTION(fft_complex,pass_7) (const BASE in[],
         }
       else
         {
-          if (sign == forward)
+          if (sign == gsl_fft_forward)
             {
               /* forward tranform */
               w1_real = GSL_REAL(twiddle1[k - 1]);
