@@ -1,10 +1,10 @@
 /* fft/c_pass_n.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -97,7 +97,7 @@ FUNCTION(fft_complex,pass_n) (BASE in[],
             w_real = 1 ;
             w_imag = 0 ;
           } else {
-            if (sign == forward) {
+            if (sign == gsl_fft_forward) {
               w_real = GSL_REAL(twiddle[idx - 1]) ;
               w_imag = GSL_IMAG(twiddle[idx - 1]) ;
             } else {
@@ -182,7 +182,7 @@ FUNCTION(fft_complex,pass_n) (BASE in[],
               ATOMIC x_imag = IMAG(in, istride,i + e1 * m);
 
               ATOMIC w_real, w_imag ;
-              if (sign == forward) {
+              if (sign == gsl_fft_forward) {
                 w_real = GSL_REAL(twiddle[(e1-1)*q + k-1]) ;
                 w_imag = GSL_IMAG(twiddle[(e1-1)*q + k-1]) ;
               } else {
