@@ -3,6 +3,7 @@
    information. */
 
 #include <config.h>
+#include <stdlib.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_test.h>
 #include <gsl/gsl_fit.h>
@@ -168,5 +169,5 @@ main (void)
 
   /* now summarize the results */
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
