@@ -1,9 +1,26 @@
+/* ieee-utils/print.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
+
 #include <config.h>
 #include <stdio.h>
 #include <math.h>
-#include <gsl_ieee_utils.h>
-
-#include "ieee_utils.h"
+#include <gsl/gsl_ieee_utils.h>
 
 /* A table of sign characters, 0=positive, 1=negative. We print a space
    instead of a unary + sign for compatibility with bc */
