@@ -1,7 +1,27 @@
 #include <config.h>
 #include <stdlib.h>
+#include <math.h>
+#include <gsl/gsl_math.h>
 #include <gsl/gsl_matrix.h>
 
+#define BASE_GSL_COMPLEX_LONG
+#include "templates_on.h"
+#include "oper_complex_source.c"
+#include "templates_off.h"
+#undef  BASE_GSL_COMPLEX_LONG
+
+#define BASE_GSL_COMPLEX
+#include "templates_on.h"
+#include "oper_complex_source.c"
+#include "templates_off.h"
+#undef  BASE_GSL_COMPLEX
+
+#define BASE_GSL_COMPLEX_FLOAT
+#include "templates_on.h"
+#include "oper_complex_source.c"
+#include "templates_off.h"
+#undef  BASE_GSL_COMPLEX_FLOAT
+
 #define BASE_LONG_DOUBLE
 #include "templates_on.h"
 #include "oper_source.c"
