@@ -313,7 +313,7 @@ test_multilarge_solve(const gsl_multilarge_linear_type * T, const double lambda,
 }
 
 static void
-test_system(const gsl_multilarge_linear_type * T,
+test_random(const gsl_multilarge_linear_type * T,
             const size_t n, const size_t p,
             const double tol,
             const gsl_rng * r)
@@ -334,8 +334,8 @@ test_system(const gsl_multilarge_linear_type * T,
   size_t i;
 
   /* generate LS system */
-  test_random_matrix_ill(X, r);
-  /*test_random_matrix(X, r, -1.0, 1.0);*/
+  /*XXXtest_random_matrix_ill(X, r);*/
+  test_random_matrix(X, r, -1.0, 1.0);
   test_random_vector(c, r, -1.0, 1.0);
 
   /* compute y = X c + noise */
@@ -354,16 +354,16 @@ test_system(const gsl_multilarge_linear_type * T,
   /* random tall L */
   test_random_matrix(Ltall, r, -10.0, 10.0);
 
-  for (i = 0; i < 2; ++i)
+  for (i = 0; i < 5; ++i)
     {
-      double lambda = pow(10.0, -(double) i);
+      double lambda = i == 0 ? 0.0 : pow(10.0, -(double) i);
 
       /* unweighted with L = I */
       {
         test_multifit_solve(lambda, X, y, NULL, NULL, NULL, &rnorm0, &snorm0, c0);
         test_multilarge_solve(T, lambda, X, y, NULL, NULL, NULL, &rnorm1, &snorm1, c1);
 
-        sprintf(str, "%s unweighted stdform n=%zu p=%zu lambda=%g",
+        sprintf(str, "random %s unweighted stdform n=%zu p=%zu lambda=%g",
                 T->name, n, p, lambda);
         test_compare_vectors(tol, c0, c1, str);
 
@@ -376,7 +376,7 @@ test_system(const gsl_multilarge_linear_type * T,
         test_multifit_solve(lambda, X, y, w, diagL, NULL, &rnorm0, &snorm0, c0);
         test_multilarge_solve(T, lambda, X, y, w, diagL, NULL, &rnorm1, &snorm1, c1);
 
-        sprintf(str, "%s weighted diag(L) n=%zu p=%zu lambda=%g",
+        sprintf(str, "random %s weighted diag(L) n=%zu p=%zu lambda=%g",
                 T->name, n, p, lambda);
         test_compare_vectors(tol, c0, c1, str);
 
@@ -389,7 +389,7 @@ test_system(const gsl_multilarge_linear_type * T,
         test_multifit_solve(lambda, X, y, NULL, diagL, NULL, &rnorm0, &snorm0, c0);
         test_multilarge_solve(T, lambda, X, y, NULL, diagL, NULL, &rnorm1, &snorm1, c1);
 
-        sprintf(str, "%s unweighted diag(L) n=%zu p=%zu lambda=%g",
+        sprintf(str, "random %s unweighted diag(L) n=%zu p=%zu lambda=%g",
                 T->name, n, p, lambda);
         test_compare_vectors(tol, c0, c1, str);
 
@@ -402,7 +402,7 @@ test_system(const gsl_multilarge_linear_type * T,
         test_multifit_solve(lambda, X, y, w, NULL, Lsqr, &rnorm0, &snorm0, c0);
         test_multilarge_solve(T, lambda, X, y, w, NULL, Lsqr, &rnorm1, &snorm1, c1);
 
-        sprintf(str, "%s weighted Lsqr n=%zu p=%zu lambda=%g",
+        sprintf(str, "random %s weighted Lsqr n=%zu p=%zu lambda=%g",
                 T->name, n, p, lambda);
         test_compare_vectors(tol, c0, c1, str);
 
@@ -415,7 +415,7 @@ test_system(const gsl_multilarge_linear_type * T,
         test_multifit_solve(lambda, X, y, NULL, NULL, Lsqr, &rnorm0, &snorm0, c0);
         test_multilarge_solve(T, lambda, X, y, NULL, NULL, Lsqr, &rnorm1, &snorm1, c1);
 
-        sprintf(str, "%s unweighted Lsqr n=%zu p=%zu lambda=%g",
+        sprintf(str, "random %s unweighted Lsqr n=%zu p=%zu lambda=%g",
                 T->name, n, p, lambda);
         test_compare_vectors(tol, c0, c1, str);
 
@@ -428,7 +428,7 @@ test_system(const gsl_multilarge_linear_type * T,
         test_multifit_solve(lambda, X, y, w, NULL, Ltall, &rnorm0, &snorm0, c0);
         test_multilarge_solve(T, lambda, X, y, w, NULL, Ltall, &rnorm1, &snorm1, c1);
 
-        sprintf(str, "%s weighted Ltall n=%zu p=%zu lambda=%g",
+        sprintf(str, "random %s weighted Ltall n=%zu p=%zu lambda=%g",
                 T->name, n, p, lambda);
         test_compare_vectors(tol, c0, c1, str);
 
@@ -441,7 +441,7 @@ test_system(const gsl_multilarge_linear_type * T,
         test_multifit_solve(lambda, X, y, NULL, NULL, Ltall, &rnorm0, &snorm0, c0);
         test_multilarge_solve(T, lambda, X, y, NULL, NULL, Ltall, &rnorm1, &snorm1, c1);
 
-        sprintf(str, "%s unweighted Ltall n=%zu p=%zu lambda=%g",
+        sprintf(str, "random %s unweighted Ltall n=%zu p=%zu lambda=%g",
                 T->name, n, p, lambda);
         test_compare_vectors(tol, c0, c1, str);
 
@@ -469,19 +469,20 @@ main (void)
   gsl_ieee_env_setup();
 
   {
-    const double tol1 = 1.0e-7;
-    const double tol2 = 1.0e-10;
-    const size_t n_vals[] = { 40, 356, 501 };
-    const size_t p_vals[] = { 40, 213, 345 };
+    const double tol1 = 1.0e-8;
+    const double tol2 = 1.0e-11;
+    const size_t n_vals[] = { 200, 356, 501 };
+    const size_t p_vals[] = { 10, 21, 34 };
     size_t i;
 
-    for (i = 0; i < 2; ++i)
+    for (i = 0; i < 1; ++i)
       {
         size_t n = n_vals[i];
         size_t p = p_vals[i];
 
-        test_system(gsl_multilarge_linear_normal, n, p, tol1, r);
-        test_system(gsl_multilarge_linear_tsqr, n, p, tol2, r);
+        /* generate random ill-conditioned LS system and test */
+        test_random(gsl_multilarge_linear_normal, n, p, tol1, r);
+        test_random(gsl_multilarge_linear_tsqr, n, p, tol2, r);
       }
   }
 
