@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
+#include <gsl/gsl_inline.h>
 #include <gsl/gsl_check_range.h>
 #include <gsl/gsl_block_char.h>
 
@@ -122,12 +123,6 @@ gsl_vector_char_const_subvector_with_stride (const gsl_vector_char *v,
 
 /* Operations */
 
-char gsl_vector_char_get (const gsl_vector_char * v, const size_t i);
-void gsl_vector_char_set (gsl_vector_char * v, const size_t i, char x);
-
-char *gsl_vector_char_ptr (gsl_vector_char * v, const size_t i);
-const char *gsl_vector_char_const_ptr (const gsl_vector_char * v, const size_t i);
-
 void gsl_vector_char_set_zero (gsl_vector_char * v);
 void gsl_vector_char_set_all (gsl_vector_char * v, char x);
 int gsl_vector_char_set_basis (gsl_vector_char * v, size_t i);
@@ -157,22 +152,31 @@ int gsl_vector_char_add (gsl_vector_char * a, const gsl_vector_char * b);
 int gsl_vector_char_sub (gsl_vector_char * a, const gsl_vector_char * b);
 int gsl_vector_char_mul (gsl_vector_char * a, const gsl_vector_char * b);
 int gsl_vector_char_div (gsl_vector_char * a, const gsl_vector_char * b);
-int gsl_vector_char_scale (gsl_vector_char * a, const double x);
+int gsl_vector_char_scale (gsl_vector_char * a, const char x);
 int gsl_vector_char_add_constant (gsl_vector_char * a, const double x);
+int gsl_vector_char_axpby (const char alpha, const gsl_vector_char * x, const char beta, gsl_vector_char * y);
+
+int gsl_vector_char_equal (const gsl_vector_char * u, 
+                            const gsl_vector_char * v);
 
 int gsl_vector_char_isnull (const gsl_vector_char * v);
 int gsl_vector_char_ispos (const gsl_vector_char * v);
 int gsl_vector_char_isneg (const gsl_vector_char * v);
 int gsl_vector_char_isnonneg (const gsl_vector_char * v);
 
+INLINE_DECL char gsl_vector_char_get (const gsl_vector_char * v, const size_t i);
+INLINE_DECL void gsl_vector_char_set (gsl_vector_char * v, const size_t i, char x);
+INLINE_DECL char * gsl_vector_char_ptr (gsl_vector_char * v, const size_t i);
+INLINE_DECL const char * gsl_vector_char_const_ptr (const gsl_vector_char * v, const size_t i);
+
 #ifdef HAVE_INLINE
 
-extern inline
+INLINE_FUN
 char
 gsl_vector_char_get (const gsl_vector_char * v, const size_t i)
 {
 #if GSL_RANGE_CHECK
-  if (i >= v->size)
+  if (GSL_RANGE_COND(i >= v->size))
     {
       GSL_ERROR_VAL ("index out of range", GSL_EINVAL, 0);
     }
@@ -180,12 +184,12 @@ gsl_vector_char_get (const gsl_vector_char * v, const size_t i)
   return v->data[i * v->stride];
 }
 
-extern inline
+INLINE_FUN
 void
 gsl_vector_char_set (gsl_vector_char * v, const size_t i, char x)
 {
 #if GSL_RANGE_CHECK
-  if (i >= v->size)
+  if (GSL_RANGE_COND(i >= v->size))
     {
       GSL_ERROR_VOID ("index out of range", GSL_EINVAL);
     }
@@ -193,12 +197,12 @@ gsl_vector_char_set (gsl_vector_char * v, const size_t i, char x)
   v->data[i * v->stride] = x;
 }
 
-extern inline
+INLINE_FUN
 char *
 gsl_vector_char_ptr (gsl_vector_char * v, const size_t i)
 {
 #if GSL_RANGE_CHECK
-  if (i >= v->size)
+  if (GSL_RANGE_COND(i >= v->size))
     {
       GSL_ERROR_NULL ("index out of range", GSL_EINVAL);
     }
@@ -206,20 +210,18 @@ gsl_vector_char_ptr (gsl_vector_char * v, const size_t i)
   return (char *) (v->data + i * v->stride);
 }
 
-extern inline
+INLINE_FUN
 const char *
 gsl_vector_char_const_ptr (const gsl_vector_char * v, const size_t i)
 {
 #if GSL_RANGE_CHECK
-  if (i >= v->size)
+  if (GSL_RANGE_COND(i >= v->size))
     {
       GSL_ERROR_NULL ("index out of range", GSL_EINVAL);
     }
 #endif
   return (const char *) (v->data + i * v->stride);
 }
-
-
 #endif /* HAVE_INLINE */
 
 __END_DECLS
