@@ -152,8 +152,12 @@ int gsl_vector_long_add (gsl_vector_long * a, const gsl_vector_long * b);
 int gsl_vector_long_sub (gsl_vector_long * a, const gsl_vector_long * b);
 int gsl_vector_long_mul (gsl_vector_long * a, const gsl_vector_long * b);
 int gsl_vector_long_div (gsl_vector_long * a, const gsl_vector_long * b);
-int gsl_vector_long_scale (gsl_vector_long * a, const double x);
+int gsl_vector_long_scale (gsl_vector_long * a, const long x);
 int gsl_vector_long_add_constant (gsl_vector_long * a, const double x);
+int gsl_vector_long_axpby (const long alpha, const gsl_vector_long * x, const long beta, gsl_vector_long * y);
+
+int gsl_vector_long_equal (const gsl_vector_long * u, 
+                            const gsl_vector_long * v);
 
 int gsl_vector_long_isnull (const gsl_vector_long * v);
 int gsl_vector_long_ispos (const gsl_vector_long * v);
