@@ -345,6 +345,47 @@ FUNCTION (test, func) (size_t stride, size_t N)
     TEST (status, "_setbasis" DESC " over range") ;
   }
 
+  {
+    int status = 0;
+    TYPE (gsl_vector) * w0 = FUNCTION (gsl_vector, alloc) (N * stride);
+    QUALIFIED_VIEW(gsl_vector,view) view2 = FUNCTION (gsl_vector, subvector_with_stride) (w0, 0, stride, N);
+    TYPE (gsl_vector) * w = &view2.vector;
+
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) i);
+        FUNCTION (gsl_vector, set) (w, i, (ATOMIC) i);
+      }
+
+    FUNCTION (gsl_vector, axpby) ((ATOMIC)2, v, (ATOMIC)3, w);
+
+    for (i = 0; i < N; i++)
+      {
+        if (FUNCTION (gsl_vector, get) (w, i) != (ATOMIC) ((ATOMIC)i*(ATOMIC)2.0 + (ATOMIC)i*(ATOMIC)3.0))
+          status = 1;
+      }
+
+    TEST (status, "_axpby" DESC " by (2,3)") ;
+
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) i);
+        FUNCTION (gsl_vector, set) (w, i, (ATOMIC) i);
+      }
+
+    FUNCTION (gsl_vector, axpby) ((ATOMIC)2, v, (ATOMIC)0, w);
+
+    for (i = 0; i < N; i++)
+      {
+        if (FUNCTION (gsl_vector, get) (w, i) != (ATOMIC) ((ATOMIC)i*(ATOMIC)2.0))
+          status = 1;
+      }
+
+    TEST (status, "_axpby" DESC " by (2,0)") ;
+
+    FUNCTION (gsl_vector, free) (w0);
+  }
+
   {
     int status = 0;
 
@@ -353,7 +394,7 @@ FUNCTION (test, func) (size_t stride, size_t N)
         FUNCTION (gsl_vector, set) (v, i, (ATOMIC) i);
       }
 
-    FUNCTION (gsl_vector, scale) (v, 2.0);
+    FUNCTION (gsl_vector, scale) (v, (ATOMIC)2.0);
 
     for (i = 0; i < N; i++)
       {
@@ -579,7 +620,6 @@ FUNCTION (test, func) (size_t stride, size_t N)
 
   }
 
-
   FUNCTION (gsl_vector, free) (v0);      /* free whatever is in v */
 }
 
